.. _contributing:

**************************
 開源貢獻 - Contributing
**************************

twstock 非常歡迎您來貢獻，參與開發與除錯。

如果你有任何的建議、功能要求或是 bug 回報，請在
`GitHub issues <https://github.com/mlouielu/twstock/issues/new>`_
開啟一個新的 issue。 如果要上傳 patch，請使用
`GitHub pull request <https://github.com/mlouielu/twstock/pulls>`_
來上傳 patch。當你的 patch 被合併時，你會自動被加入到
`Contributors List <https://github.com/mlouielu/twstock/graphs/contributors>`_
當中。

Coding Style Guide
------------------

Coding Style 請遵循，並參照 `PEP 8 <https://www.python.org/dev/peps/pep-0008/>`_。
